* dummypdf 1.0.0 (2017-12-12)

    * No changes since previous version.

    -- Louis Paternault <spalax+python@gresille.org>

* dummypdf 0.3.0 (2017-03-12)

    * Null paper sizes (e.g. `--papersize=0cmx1cm`) are no longer ignored (closes #2).
    * New option `--list`: it is now possible to create files with several page sizes (closes #3).
    * Add python3.6 support.
    * Add regression tests.

    -- Louis Paternault <spalax+python@gresille.org>

* dummypdf 0.2.1 (2016-10-14)

    * Move help about available color names into a separate "--list-colors" option.

    -- Louis Paternault <spalax+python@gresille.org>

* dummypdf 0.2.0 (2016-05-21)

    * Can generate PDFs with no pages.
    * Can be called using `python -m dummypdf`.
    * Several minor improvements to setup.

    -- Louis Paternault <spalax+python@gresille.org>

* dummypdf 0.1.1 (2015-06-13)

    * Several minor improvements to setup, test and documentation.

    -- Louis Paternault <spalax+python@gresille.org>

* dummypdf 0.1.0 (2015-03-15)

    * First published version.

    -- Louis Paternault <spalax+python@gresille.org>
